Package: CohortConstructor
Title: Build and Manipulate Study Cohorts Using a Common Data Model
Version: 0.6.3
Authors@R: c(
    person("Edward", "Burn", , "edward.burn@ndorms.ox.ac.uk", 
    role = c("aut", "cre"), comment = c(ORCID = "0000-0002-9286-1128")),
    person("Martí", "Català", , "marti.catalasabate@ndorms.ox.ac.uk", 
    role = c("aut"), comment = c(ORCID = "0000-0003-3308-9905")),
    person("Nuria", "Mercade-Besora", , "nuria.mercadebesora@ndorms.ox.ac.uk", 
    role = c("aut"), comment = c(ORCID = "0009-0006-7948-3747")),
    person("Marta", "Alcalde-Herraiz", , "marta.alcaldeherraiz@ndorms.ox.ac.uk", 
    role = c("aut"), comment = c(ORCID = "0009-0002-4405-1814")),
    person("Mike", "Du", , "mike.du@ndorms.ox.ac.uk", 
    role = c("aut"), comment = c(ORCID = "0000-0002-9517-8834")),
    person("Yuchen", "Guo", email = "yuchen.guo@ndorms.ox.ac.uk", 
    role = c("aut"), comment = c(ORCID = "0000-0002-0847-4855")),
    person("Xihang", "Chen", , "xihang.chen@ndorms.ox.ac.uk", 
    role = c("aut"), comment = c(ORCID = "0009-0001-8112-8959")),
    person("Kim", "Lopez-Guell", , "kim.lopez@spc.ox.ac.uk", 
    role = "aut", comment = c(ORCID = "0000-0002-8462-8668")),
    person("Elin", "Rowlands", , "elin.rowlands@ndorms.ox.ac.uk", 
    role = "aut", comment = c(ORCID = "0009-0005-5166-0417")))
Description: Create and manipulate study cohorts in data mapped to the 
    Observational Medical Outcomes Partnership Common Data Model.
License: Apache License (>= 2)
Encoding: UTF-8
RoxygenNote: 7.3.3
Imports: cli, clock, dplyr, glue, omopgenerics (>= 1.3.2),
        PatientProfiles (>= 1.4.4), CodelistGenerator (>= 4.0.0),
        purrr, rlang, tibble, tidyr, utils
Suggests: CDMConnector (>= 1.7.0), CirceR, CohortCharacteristics, covr,
        DBI, DiagrammeR, DrugUtilisation, duckdb, ggplot2, gt, here,
        IncidencePrevalence, knitr, odbc, omock (>= 0.5.0), rmarkdown,
        RPostgres, scales, SqlRender, stringr, testthat (>= 3.0.0),
        tictoc, visOmopResults, systemfonts
Config/testthat/edition: 3
Config/testthat/parallel: true
VignetteBuilder: knitr
Depends: R (>= 4.1)
URL: https://ohdsi.github.io/CohortConstructor/,
        https://github.com/OHDSI/CohortConstructor
BugReports: https://github.com/OHDSI/CohortConstructor/issues
LazyData: true
NeedsCompilation: no
Packaged: 2026-03-30 06:56:32 UTC; orms0426
Author: Edward Burn [aut, cre] (ORCID: <https://orcid.org/0000-0002-9286-1128>),
  Martí Català [aut] (ORCID: <https://orcid.org/0000-0003-3308-9905>),
  Nuria Mercade-Besora [aut] (ORCID:
    <https://orcid.org/0009-0006-7948-3747>),
  Marta Alcalde-Herraiz [aut] (ORCID:
    <https://orcid.org/0009-0002-4405-1814>),
  Mike Du [aut] (ORCID: <https://orcid.org/0000-0002-9517-8834>),
  Yuchen Guo [aut] (ORCID: <https://orcid.org/0000-0002-0847-4855>),
  Xihang Chen [aut] (ORCID: <https://orcid.org/0009-0001-8112-8959>),
  Kim Lopez-Guell [aut] (ORCID: <https://orcid.org/0000-0002-8462-8668>),
  Elin Rowlands [aut] (ORCID: <https://orcid.org/0009-0005-5166-0417>)
Maintainer: Edward Burn <edward.burn@ndorms.ox.ac.uk>
Repository: CRAN
Date/Publication: 2026-03-30 08:00:02 UTC
Built: R 4.6.0; ; 2026-04-30 19:22:41 UTC; unix
