# Generated by roxygen2: do not edit by hand

export(addCohortTableIndex)
export(attrition)
export(benchmarkCohortConstructor)
export(bind)
export(cohortCodelist)
export(cohortCount)
export(collapseCohorts)
export(conceptCohort)
export(copyCohorts)
export(deathCohort)
export(demographicsCohort)
export(endDateColumn)
export(entryAtFirstDate)
export(entryAtLastDate)
export(exitAtDeath)
export(exitAtFirstDate)
export(exitAtLastDate)
export(exitAtObservationEnd)
export(intersectCohorts)
export(matchCohorts)
export(measurementCohort)
export(mockCohortConstructor)
export(padCohortDate)
export(padCohortEnd)
export(padCohortStart)
export(renameCohort)
export(requireAge)
export(requireCohortIntersect)
export(requireConceptIntersect)
export(requireDemographics)
export(requireDuration)
export(requireFutureObservation)
export(requireInDateRange)
export(requireIsEntry)
export(requireIsFirstEntry)
export(requireIsLastEntry)
export(requireMinCohortCount)
export(requirePriorObservation)
export(requireSex)
export(requireTableIntersect)
export(sampleCohorts)
export(settings)
export(startDateColumn)
export(stratifyCohorts)
export(subsetCohorts)
export(tableName)
export(timeWindowCohorts)
export(trimDemographics)
export(trimDuration)
export(trimToDateRange)
export(unionCohorts)
export(yearCohorts)
importFrom(PatientProfiles,endDateColumn)
importFrom(PatientProfiles,startDateColumn)
importFrom(omopgenerics,attrition)
importFrom(omopgenerics,bind)
importFrom(omopgenerics,cohortCodelist)
importFrom(omopgenerics,cohortCount)
importFrom(omopgenerics,settings)
importFrom(omopgenerics,tableName)
importFrom(rlang,":=")
importFrom(rlang,.data)
importFrom(rlang,.env)
importFrom(utils,data)
